Class: Google::Apis::CloudchannelV1::GoogleCloudChannelV1ChangeRenewalSettingsRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudchannel_v1/classes.rb,
lib/google/apis/cloudchannel_v1/representations.rb,
lib/google/apis/cloudchannel_v1/representations.rb

Overview

Request message for CloudChannelService.ChangeRenewalSettings.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudChannelV1ChangeRenewalSettingsRequest

Returns a new instance of GoogleCloudChannelV1ChangeRenewalSettingsRequest.



352
353
354
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 352

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#renewal_settingsGoogle::Apis::CloudchannelV1::GoogleCloudChannelV1RenewalSettings

Renewal settings for renewable Offers. Corresponds to the JSON property renewalSettings



338
339
340
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 338

def renewal_settings
  @renewal_settings
end

#request_idString

Optional. You can specify an optional unique request ID, and if you need to retry your request, the server will know to ignore the request if it's complete. For example, you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if it received the original operation with the same request ID. If it did, it will ignore the second request. The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000). Corresponds to the JSON property requestId

Returns:

  • (String)


350
351
352
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 350

def request_id
  @request_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



357
358
359
360
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 357

def update!(**args)
  @renewal_settings = args[:renewal_settings] if args.key?(:renewal_settings)
  @request_id = args[:request_id] if args.key?(:request_id)
end