Class: Google::Apis::CloudchannelV1::GoogleCloudChannelV1CreateEntitlementRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudchannel_v1/classes.rb,
lib/google/apis/cloudchannel_v1/representations.rb,
lib/google/apis/cloudchannel_v1/representations.rb

Overview

Request message for CloudChannelService.CreateEntitlement

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudChannelV1CreateEntitlementRequest

Returns a new instance of GoogleCloudChannelV1CreateEntitlementRequest.



821
822
823
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 821

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#entitlementGoogle::Apis::CloudchannelV1::GoogleCloudChannelV1Entitlement

An entitlement is a representation of a customer's ability to use a service. Corresponds to the JSON property entitlement



807
808
809
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 807

def entitlement
  @entitlement
end

#request_idString

Optional. You can specify an optional unique request ID, and if you need to retry your request, the server will know to ignore the request if it's complete. For example, you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if it received the original operation with the same request ID. If it did, it will ignore the second request. The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000). Corresponds to the JSON property requestId

Returns:

  • (String)


819
820
821
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 819

def request_id
  @request_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



826
827
828
829
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 826

def update!(**args)
  @entitlement = args[:entitlement] if args.key?(:entitlement)
  @request_id = args[:request_id] if args.key?(:request_id)
end