Class: Google::Apis::CloudchannelV1::GoogleCloudChannelV1ListProductsResponse
- Inherits:
-
Object
- Object
- Google::Apis::CloudchannelV1::GoogleCloudChannelV1ListProductsResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudchannel_v1/classes.rb,
lib/google/apis/cloudchannel_v1/representations.rb,
lib/google/apis/cloudchannel_v1/representations.rb
Overview
Response message for ListProducts.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token to retrieve the next page of results.
-
#products ⇒ Array<Google::Apis::CloudchannelV1::GoogleCloudChannelV1Product>
List of Products requested.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudChannelV1ListProductsResponse
constructor
A new instance of GoogleCloudChannelV1ListProductsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudChannelV1ListProductsResponse
Returns a new instance of GoogleCloudChannelV1ListProductsResponse.
1743 1744 1745 |
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 1743 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token to retrieve the next page of results.
Corresponds to the JSON property nextPageToken
1736 1737 1738 |
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 1736 def next_page_token @next_page_token end |
#products ⇒ Array<Google::Apis::CloudchannelV1::GoogleCloudChannelV1Product>
List of Products requested.
Corresponds to the JSON property products
1741 1742 1743 |
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 1741 def products @products end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1748 1749 1750 1751 |
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 1748 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @products = args[:products] if args.key?(:products) end |