Class: Google::Apis::CloudchannelV1::GoogleCloudChannelV1ListTransferableOffersResponse
- Inherits:
-
Object
- Object
- Google::Apis::CloudchannelV1::GoogleCloudChannelV1ListTransferableOffersResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudchannel_v1/classes.rb,
lib/google/apis/cloudchannel_v1/representations.rb,
lib/google/apis/cloudchannel_v1/representations.rb
Overview
Response message for CloudChannelService.ListTransferableOffers.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token to retrieve the next page of results.
-
#transferable_offers ⇒ Array<Google::Apis::CloudchannelV1::GoogleCloudChannelV1TransferableOffer>
Information about Offers for a customer that can be used for transfer.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudChannelV1ListTransferableOffersResponse
constructor
A new instance of GoogleCloudChannelV1ListTransferableOffersResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudChannelV1ListTransferableOffersResponse
Returns a new instance of GoogleCloudChannelV1ListTransferableOffersResponse.
2019 2020 2021 |
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 2019 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token to retrieve the next page of results. Pass to
ListTransferableOffersRequest.page_token to obtain that page.
Corresponds to the JSON property nextPageToken
2012 2013 2014 |
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 2012 def next_page_token @next_page_token end |
#transferable_offers ⇒ Array<Google::Apis::CloudchannelV1::GoogleCloudChannelV1TransferableOffer>
Information about Offers for a customer that can be used for transfer.
Corresponds to the JSON property transferableOffers
2017 2018 2019 |
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 2017 def transferable_offers @transferable_offers end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2024 2025 2026 2027 |
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 2024 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @transferable_offers = args[:transferable_offers] if args.key?(:transferable_offers) end |