Class: Google::Apis::CloudchannelV1::GoogleCloudChannelV1Price

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudchannel_v1/classes.rb,
lib/google/apis/cloudchannel_v1/representations.rb,
lib/google/apis/cloudchannel_v1/representations.rb

Overview

Represents the price of the Offer.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudChannelV1Price

Returns a new instance of GoogleCloudChannelV1Price.



2492
2493
2494
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 2492

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#base_priceGoogle::Apis::CloudchannelV1::GoogleTypeMoney

Represents an amount of money with its currency type. Corresponds to the JSON property basePrice



2463
2464
2465
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 2463

def base_price
  @base_price
end

#discountFloat

Discount percentage, represented as decimal. For example, a 20% discount will be represent as 0.2. Corresponds to the JSON property discount

Returns:

  • (Float)


2469
2470
2471
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 2469

def discount
  @discount
end

#discount_componentsArray<Google::Apis::CloudchannelV1::GoogleCloudChannelV1DiscountComponent>

Breakdown of the discount into its components. This will be empty if there is no discount present. Corresponds to the JSON property discountComponents



2475
2476
2477
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 2475

def discount_components
  @discount_components
end

#effective_priceGoogle::Apis::CloudchannelV1::GoogleTypeMoney

Represents an amount of money with its currency type. Corresponds to the JSON property effectivePrice



2480
2481
2482
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 2480

def effective_price
  @effective_price
end

#external_price_uriString

Link to external price list, such as link to Google Voice rate card. Corresponds to the JSON property externalPriceUri

Returns:

  • (String)


2485
2486
2487
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 2485

def external_price_uri
  @external_price_uri
end

#price_periodGoogle::Apis::CloudchannelV1::GoogleCloudChannelV1Period

Represents period in days/months/years. Corresponds to the JSON property pricePeriod



2490
2491
2492
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 2490

def price_period
  @price_period
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2497
2498
2499
2500
2501
2502
2503
2504
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 2497

def update!(**args)
  @base_price = args[:base_price] if args.key?(:base_price)
  @discount = args[:discount] if args.key?(:discount)
  @discount_components = args[:discount_components] if args.key?(:discount_components)
  @effective_price = args[:effective_price] if args.key?(:effective_price)
  @external_price_uri = args[:external_price_uri] if args.key?(:external_price_uri)
  @price_period = args[:price_period] if args.key?(:price_period)
end