Class: Google::Apis::CloudchannelV1::GoogleCloudChannelV1PurchasableOffer

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudchannel_v1/classes.rb,
lib/google/apis/cloudchannel_v1/representations.rb,
lib/google/apis/cloudchannel_v1/representations.rb

Overview

Offer that you can purchase for a customer. This is used in the ListPurchasableOffer API response.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudChannelV1PurchasableOffer

Returns a new instance of GoogleCloudChannelV1PurchasableOffer.



2726
2727
2728
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 2726

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#offerGoogle::Apis::CloudchannelV1::GoogleCloudChannelV1Offer

Represents an offer made to resellers for purchase. An offer is associated with a Sku, has a plan for payment, a price, and defines the constraints for buying. Corresponds to the JSON property offer



2717
2718
2719
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 2717

def offer
  @offer
end

#price_reference_idString

Optional. Price reference ID for the offer. Only for offers that require additional price information. Used to guarantee that the pricing is consistent between quoting the offer and placing the order. Corresponds to the JSON property priceReferenceId

Returns:

  • (String)


2724
2725
2726
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 2724

def price_reference_id
  @price_reference_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2731
2732
2733
2734
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 2731

def update!(**args)
  @offer = args[:offer] if args.key?(:offer)
  @price_reference_id = args[:price_reference_id] if args.key?(:price_reference_id)
end