Class: Google::Apis::CloudchannelV1::GoogleCloudChannelV1ReportValue

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudchannel_v1/classes.rb,
lib/google/apis/cloudchannel_v1/representations.rb,
lib/google/apis/cloudchannel_v1/representations.rb

Overview

A single report value.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudChannelV1ReportValue

Returns a new instance of GoogleCloudChannelV1ReportValue.



3071
3072
3073
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 3071

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#date_time_valueGoogle::Apis::CloudchannelV1::GoogleTypeDateTime

Represents civil time (or occasionally physical time). This type can represent a civil time in one of a few possible ways: * When utc_offset is set and time_zone is unset: a civil time on a calendar day with a particular offset from UTC. * When time_zone is set and utc_offset is unset: a civil time on a calendar day in a particular time zone. * When neither time_zone nor utc_offset is set: a civil time on a calendar day in local time. The date is relative to the Proleptic Gregorian Calendar. If year, month, or day are 0, the DateTime is considered not to have a specific year, month, or day respectively. This type may also be used to represent a physical time if all the date and time fields are set and either case of the time_offset oneof is set. Consider using Timestamp message for physical time instead. If your use case also would like to store the user's timezone, that can be done in another field. This type is more flexible than some applications may want. Make sure to document and validate your application's limitations. Corresponds to the JSON property dateTimeValue



3034
3035
3036
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 3034

def date_time_value
  @date_time_value
end

#date_valueGoogle::Apis::CloudchannelV1::GoogleTypeDate

Represents a whole or partial calendar date, such as a birthday. The time of day and time zone are either specified elsewhere or are insignificant. The date is relative to the Gregorian Calendar. This can represent one of the following: * A full date, with non-zero year, month, and day values. * A month and day, with a zero year (for example, an anniversary). * A year on its own, with a zero month and a zero day. * A year and month, with a zero day (for example, a credit card expiration date). Related types: * google.type. TimeOfDay * google.type.DateTime * google.protobuf.Timestamp Corresponds to the JSON property dateValue



3046
3047
3048
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 3046

def date_value
  @date_value
end

#decimal_valueGoogle::Apis::CloudchannelV1::GoogleTypeDecimal

A representation of a decimal value, such as 2.5. Clients may convert values into language-native decimal formats, such as Java's BigDecimal or Python's decimal.Decimal. Corresponds to the JSON property decimalValue



3054
3055
3056
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 3054

def decimal_value
  @decimal_value
end

#int_valueFixnum

A value of type int. Corresponds to the JSON property intValue

Returns:

  • (Fixnum)


3059
3060
3061
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 3059

def int_value
  @int_value
end

#money_valueGoogle::Apis::CloudchannelV1::GoogleTypeMoney

Represents an amount of money with its currency type. Corresponds to the JSON property moneyValue



3064
3065
3066
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 3064

def money_value
  @money_value
end

#string_valueString

A value of type string. Corresponds to the JSON property stringValue

Returns:

  • (String)


3069
3070
3071
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 3069

def string_value
  @string_value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3076
3077
3078
3079
3080
3081
3082
3083
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 3076

def update!(**args)
  @date_time_value = args[:date_time_value] if args.key?(:date_time_value)
  @date_value = args[:date_value] if args.key?(:date_value)
  @decimal_value = args[:decimal_value] if args.key?(:decimal_value)
  @int_value = args[:int_value] if args.key?(:int_value)
  @money_value = args[:money_value] if args.key?(:money_value)
  @string_value = args[:string_value] if args.key?(:string_value)
end