Class: Google::Apis::CloudchannelV1::GoogleCloudChannelV1StartPaidServiceRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudchannel_v1/classes.rb,
lib/google/apis/cloudchannel_v1/representations.rb,
lib/google/apis/cloudchannel_v1/representations.rb

Overview

Request message for CloudChannelService.StartPaidService.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudChannelV1StartPaidServiceRequest

Returns a new instance of GoogleCloudChannelV1StartPaidServiceRequest.



3439
3440
3441
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 3439

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#request_idString

Optional. You can specify an optional unique request ID, and if you need to retry your request, the server will know to ignore the request if it's complete. For example, you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if it received the original operation with the same request ID. If it did, it will ignore the second request. The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000). Corresponds to the JSON property requestId

Returns:

  • (String)


3437
3438
3439
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 3437

def request_id
  @request_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3444
3445
3446
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 3444

def update!(**args)
  @request_id = args[:request_id] if args.key?(:request_id)
end