Class: Google::Apis::CloudchannelV1::GoogleCloudChannelV1SuspendEntitlementRequest
- Inherits:
-
Object
- Object
- Google::Apis::CloudchannelV1::GoogleCloudChannelV1SuspendEntitlementRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudchannel_v1/classes.rb,
lib/google/apis/cloudchannel_v1/representations.rb,
lib/google/apis/cloudchannel_v1/representations.rb
Overview
Request message for CloudChannelService.SuspendEntitlement.
Instance Attribute Summary collapse
-
#request_id ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudChannelV1SuspendEntitlementRequest
constructor
A new instance of GoogleCloudChannelV1SuspendEntitlementRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudChannelV1SuspendEntitlementRequest
Returns a new instance of GoogleCloudChannelV1SuspendEntitlementRequest.
3491 3492 3493 |
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 3491 def initialize(**args) update!(**args) end |
Instance Attribute Details
#request_id ⇒ String
Optional. You can specify an optional unique request ID, and if you need to
retry your request, the server will know to ignore the request if it's
complete. For example, you make an initial request and the request times out.
If you make the request again with the same request ID, the server can check
if it received the original operation with the same request ID. If it did, it
will ignore the second request. The request ID must be a valid UUID with the exception that zero UUID is not
supported (00000000-0000-0000-0000-000000000000).
Corresponds to the JSON property requestId
3489 3490 3491 |
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 3489 def request_id @request_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3496 3497 3498 |
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 3496 def update!(**args) @request_id = args[:request_id] if args.key?(:request_id) end |