Class: Google::Apis::CloudchannelV1::GoogleCloudChannelV1TransferEntitlementsRequest
- Inherits:
-
Object
- Object
- Google::Apis::CloudchannelV1::GoogleCloudChannelV1TransferEntitlementsRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudchannel_v1/classes.rb,
lib/google/apis/cloudchannel_v1/representations.rb,
lib/google/apis/cloudchannel_v1/representations.rb
Overview
Request message for CloudChannelService.TransferEntitlements.
Instance Attribute Summary collapse
-
#auth_token ⇒ String
The super admin of the resold customer generates this token to authorize a reseller to access their Cloud Identity and purchase entitlements on their behalf.
-
#entitlements ⇒ Array<Google::Apis::CloudchannelV1::GoogleCloudChannelV1Entitlement>
Required.
-
#request_id ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudChannelV1TransferEntitlementsRequest
constructor
A new instance of GoogleCloudChannelV1TransferEntitlementsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudChannelV1TransferEntitlementsRequest
Returns a new instance of GoogleCloudChannelV1TransferEntitlementsRequest.
3559 3560 3561 |
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 3559 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auth_token ⇒ String
The super admin of the resold customer generates this token to authorize a
reseller to access their Cloud Identity and purchase entitlements on their
behalf. You can omit this token after authorization. See https://support.
google.com/a/answer/7643790 for more details.
Corresponds to the JSON property authToken
3540 3541 3542 |
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 3540 def auth_token @auth_token end |
#entitlements ⇒ Array<Google::Apis::CloudchannelV1::GoogleCloudChannelV1Entitlement>
Required. The new entitlements to create or transfer.
Corresponds to the JSON property entitlements
3545 3546 3547 |
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 3545 def entitlements @entitlements end |
#request_id ⇒ String
Optional. You can specify an optional unique request ID, and if you need to
retry your request, the server will know to ignore the request if it's
complete. For example, you make an initial request and the request times out.
If you make the request again with the same request ID, the server can check
if it received the original operation with the same request ID. If it did, it
will ignore the second request. The request ID must be a valid UUID with the exception that zero UUID is not
supported (00000000-0000-0000-0000-000000000000).
Corresponds to the JSON property requestId
3557 3558 3559 |
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 3557 def request_id @request_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3564 3565 3566 3567 3568 |
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 3564 def update!(**args) @auth_token = args[:auth_token] if args.key?(:auth_token) @entitlements = args[:entitlements] if args.key?(:entitlements) @request_id = args[:request_id] if args.key?(:request_id) end |