Class: Google::Apis::CloudchannelV1::GoogleCloudChannelV1TransferEntitlementsToGoogleRequest
- Inherits:
-
Object
- Object
- Google::Apis::CloudchannelV1::GoogleCloudChannelV1TransferEntitlementsToGoogleRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudchannel_v1/classes.rb,
lib/google/apis/cloudchannel_v1/representations.rb,
lib/google/apis/cloudchannel_v1/representations.rb
Overview
Request message for CloudChannelService.TransferEntitlementsToGoogle.
Instance Attribute Summary collapse
-
#entitlements ⇒ Array<Google::Apis::CloudchannelV1::GoogleCloudChannelV1Entitlement>
Required.
-
#request_id ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudChannelV1TransferEntitlementsToGoogleRequest
constructor
A new instance of GoogleCloudChannelV1TransferEntitlementsToGoogleRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudChannelV1TransferEntitlementsToGoogleRequest
Returns a new instance of GoogleCloudChannelV1TransferEntitlementsToGoogleRequest.
3612 3613 3614 |
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 3612 def initialize(**args) update!(**args) end |
Instance Attribute Details
#entitlements ⇒ Array<Google::Apis::CloudchannelV1::GoogleCloudChannelV1Entitlement>
Required. The entitlements to transfer to Google.
Corresponds to the JSON property entitlements
3598 3599 3600 |
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 3598 def entitlements @entitlements end |
#request_id ⇒ String
Optional. You can specify an optional unique request ID, and if you need to
retry your request, the server will know to ignore the request if it's
complete. For example, you make an initial request and the request times out.
If you make the request again with the same request ID, the server can check
if it received the original operation with the same request ID. If it did, it
will ignore the second request. The request ID must be a valid UUID with the exception that zero UUID is not
supported (00000000-0000-0000-0000-000000000000).
Corresponds to the JSON property requestId
3610 3611 3612 |
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 3610 def request_id @request_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3617 3618 3619 3620 |
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 3617 def update!(**args) @entitlements = args[:entitlements] if args.key?(:entitlements) @request_id = args[:request_id] if args.key?(:request_id) end |