Class: Google::Apis::CloudchannelV1::GoogleCloudChannelV1alpha1ProvisionedService

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudchannel_v1/classes.rb,
lib/google/apis/cloudchannel_v1/representations.rb,
lib/google/apis/cloudchannel_v1/representations.rb

Overview

Service provisioned for an entitlement.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudChannelV1alpha1ProvisionedService

Returns a new instance of GoogleCloudChannelV1alpha1ProvisionedService.



4366
4367
4368
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 4366

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#product_idString

Output only. The product pertaining to the provisioning resource as specified in the Offer. Corresponds to the JSON property productId

Returns:

  • (String)


4351
4352
4353
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 4351

def product_id
  @product_id
end

#provisioning_idString

Output only. Provisioning ID of the entitlement. For Google Workspace, this is the underlying Subscription ID. For Google Cloud, this is the Billing Account ID of the billing subaccount. Corresponds to the JSON property provisioningId

Returns:

  • (String)


4358
4359
4360
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 4358

def provisioning_id
  @provisioning_id
end

#sku_idString

Output only. The SKU pertaining to the provisioning resource as specified in the Offer. Corresponds to the JSON property skuId

Returns:

  • (String)


4364
4365
4366
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 4364

def sku_id
  @sku_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4371
4372
4373
4374
4375
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 4371

def update!(**args)
  @product_id = args[:product_id] if args.key?(:product_id)
  @provisioning_id = args[:provisioning_id] if args.key?(:provisioning_id)
  @sku_id = args[:sku_id] if args.key?(:sku_id)
end