Class: Google::Apis::CloudchannelV1::GoogleCloudChannelV1alpha1ReportResultsMetadata

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudchannel_v1/classes.rb,
lib/google/apis/cloudchannel_v1/representations.rb,
lib/google/apis/cloudchannel_v1/representations.rb

Overview

The features describing the data. Returned by CloudChannelReportsService. RunReportJob and CloudChannelReportsService.FetchReportResults.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudChannelV1alpha1ReportResultsMetadata

Returns a new instance of GoogleCloudChannelV1alpha1ReportResultsMetadata.



4530
4531
4532
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 4530

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#date_rangeGoogle::Apis::CloudchannelV1::GoogleCloudChannelV1alpha1DateRange

A representation of usage or invoice date ranges. Corresponds to the JSON property dateRange



4512
4513
4514
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 4512

def date_range
  @date_range
end

#preceding_date_rangeGoogle::Apis::CloudchannelV1::GoogleCloudChannelV1alpha1DateRange

A representation of usage or invoice date ranges. Corresponds to the JSON property precedingDateRange



4517
4518
4519
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 4517

def preceding_date_range
  @preceding_date_range
end

#reportGoogle::Apis::CloudchannelV1::GoogleCloudChannelV1alpha1Report

The ID and description of a report that was used to generate report data. For example, "Google Cloud Daily Spend", "Google Workspace License Activity", etc. Corresponds to the JSON property report



4523
4524
4525
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 4523

def report
  @report
end

#row_countFixnum

The total number of rows of data in the final report. Corresponds to the JSON property rowCount

Returns:

  • (Fixnum)


4528
4529
4530
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 4528

def row_count
  @row_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4535
4536
4537
4538
4539
4540
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 4535

def update!(**args)
  @date_range = args[:date_range] if args.key?(:date_range)
  @preceding_date_range = args[:preceding_date_range] if args.key?(:preceding_date_range)
  @report = args[:report] if args.key?(:report)
  @row_count = args[:row_count] if args.key?(:row_count)
end