Class: Google::Apis::CloudchannelV1::GoogleLongrunningListOperationsResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudchannel_v1/classes.rb,
lib/google/apis/cloudchannel_v1/representations.rb,
lib/google/apis/cloudchannel_v1/representations.rb

Overview

The response message for Operations.ListOperations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleLongrunningListOperationsResponse

Returns a new instance of GoogleLongrunningListOperationsResponse.



4767
4768
4769
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 4767

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

The standard List next-page token. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


4752
4753
4754
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 4752

def next_page_token
  @next_page_token
end

#operationsArray<Google::Apis::CloudchannelV1::GoogleLongrunningOperation>

A list of operations that matches the specified filter in the request. Corresponds to the JSON property operations



4757
4758
4759
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 4757

def operations
  @operations
end

#unreachableArray<String>

Unordered list. Unreachable resources. Populated when the request sets ListOperationsRequest.return_partial_success and reads across collections. For example, when attempting to list all resources across all supported locations. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


4765
4766
4767
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 4765

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4772
4773
4774
4775
4776
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 4772

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @operations = args[:operations] if args.key?(:operations)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end