Class: Google::Apis::CloudchannelV1::GoogleCloudChannelV1ChangeParametersRequest
- Inherits:
-
Object
- Object
- Google::Apis::CloudchannelV1::GoogleCloudChannelV1ChangeParametersRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudchannel_v1/classes.rb,
lib/google/apis/cloudchannel_v1/representations.rb,
lib/google/apis/cloudchannel_v1/representations.rb
Overview
Request message for CloudChannelService.ChangeParameters.
Instance Attribute Summary collapse
-
#parameters ⇒ Array<Google::Apis::CloudchannelV1::GoogleCloudChannelV1Parameter>
Required.
-
#purchase_order_id ⇒ String
Optional.
-
#request_id ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudChannelV1ChangeParametersRequest
constructor
A new instance of GoogleCloudChannelV1ChangeParametersRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudChannelV1ChangeParametersRequest
Returns a new instance of GoogleCloudChannelV1ChangeParametersRequest.
319 320 321 |
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 319 def initialize(**args) update!(**args) end |
Instance Attribute Details
#parameters ⇒ Array<Google::Apis::CloudchannelV1::GoogleCloudChannelV1Parameter>
Required. Entitlement parameters to update. You can only change editable
parameters. To view the available Parameters for a request, refer to the Offer.
parameter_definitions from the desired offer.
Corresponds to the JSON property parameters
300 301 302 |
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 300 def parameters @parameters end |
#purchase_order_id ⇒ String
Optional. Purchase order ID provided by the reseller.
Corresponds to the JSON property purchaseOrderId
305 306 307 |
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 305 def purchase_order_id @purchase_order_id end |
#request_id ⇒ String
Optional. You can specify an optional unique request ID, and if you need to
retry your request, the server will know to ignore the request if it's
complete. For example, you make an initial request and the request times out.
If you make the request again with the same request ID, the server can check
if it received the original operation with the same request ID. If it did, it
will ignore the second request. The request ID must be a valid UUID with the exception that zero UUID is not
supported (00000000-0000-0000-0000-000000000000).
Corresponds to the JSON property requestId
317 318 319 |
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 317 def request_id @request_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
324 325 326 327 328 |
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 324 def update!(**args) @parameters = args[:parameters] if args.key?(:parameters) @purchase_order_id = args[:purchase_order_id] if args.key?(:purchase_order_id) @request_id = args[:request_id] if args.key?(:request_id) end |