Class: Google::Apis::CloudchannelV1::GoogleCloudChannelV1CheckCloudIdentityAccountsExistRequest
- Inherits:
-
Object
- Object
- Google::Apis::CloudchannelV1::GoogleCloudChannelV1CheckCloudIdentityAccountsExistRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudchannel_v1/classes.rb,
lib/google/apis/cloudchannel_v1/representations.rb,
lib/google/apis/cloudchannel_v1/representations.rb
Overview
Request message for CloudChannelService.CheckCloudIdentityAccountsExist.
Instance Attribute Summary collapse
-
#domain ⇒ String
Required.
-
#primary_admin_email ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudChannelV1CheckCloudIdentityAccountsExistRequest
constructor
A new instance of GoogleCloudChannelV1CheckCloudIdentityAccountsExistRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudChannelV1CheckCloudIdentityAccountsExistRequest
Returns a new instance of GoogleCloudChannelV1CheckCloudIdentityAccountsExistRequest.
480 481 482 |
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 480 def initialize(**args) update!(**args) end |
Instance Attribute Details
#domain ⇒ String
Required. Domain to fetch for Cloud Identity account customers, including
domain and team customers. For team customers, please use the domain for their
emails.
Corresponds to the JSON property domain
472 473 474 |
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 472 def domain @domain end |
#primary_admin_email ⇒ String
Optional. Primary admin email to fetch for Cloud Identity account team
customer.
Corresponds to the JSON property primaryAdminEmail
478 479 480 |
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 478 def primary_admin_email @primary_admin_email end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
485 486 487 488 |
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 485 def update!(**args) @domain = args[:domain] if args.key?(:domain) @primary_admin_email = args[:primary_admin_email] if args.key?(:primary_admin_email) end |