Class: Google::Apis::CloudchannelV1::GoogleCloudChannelV1Customer

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudchannel_v1/classes.rb,
lib/google/apis/cloudchannel_v1/representations.rb,
lib/google/apis/cloudchannel_v1/representations.rb

Overview

Entity representing a customer of a reseller or distributor.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudChannelV1Customer

Returns a new instance of GoogleCloudChannelV1Customer.



928
929
930
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 928

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#alternate_emailString

Secondary contact email. You need to provide an alternate email to create different domains if a primary contact email already exists. Users will receive a notification with credentials when you create an admin.google.com account. Secondary emails are also recovery email addresses. Alternate emails are optional when you create Team customers. Corresponds to the JSON property alternateEmail

Returns:

  • (String)


843
844
845
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 843

def alternate_email
  @alternate_email
end

#channel_partner_idString

Cloud Identity ID of the customer's channel partner. Populated only if a channel partner exists for this customer. Corresponds to the JSON property channelPartnerId

Returns:

  • (String)


849
850
851
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 849

def channel_partner_id
  @channel_partner_id
end

#cloud_identity_idString

Output only. The customer's Cloud Identity ID if the customer has a Cloud Identity resource. Corresponds to the JSON property cloudIdentityId

Returns:

  • (String)


855
856
857
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 855

def cloud_identity_id
  @cloud_identity_id
end

#cloud_identity_infoGoogle::Apis::CloudchannelV1::GoogleCloudChannelV1CloudIdentityInfo

Cloud Identity information for the Cloud Channel Customer. Corresponds to the JSON property cloudIdentityInfo



860
861
862
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 860

def cloud_identity_info
  @cloud_identity_info
end

#correlation_idString

Optional. External CRM ID for the customer. Populated only if a CRM ID exists for this customer. Corresponds to the JSON property correlationId

Returns:

  • (String)


866
867
868
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 866

def correlation_id
  @correlation_id
end

#create_timeString

Output only. Time when the customer was created. Corresponds to the JSON property createTime

Returns:

  • (String)


871
872
873
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 871

def create_time
  @create_time
end

#customer_attestation_stateString

Optional. Indicate if a customer is attesting about the correctness of provided information. Only required if creating a GCP Entitlement. Corresponds to the JSON property customerAttestationState

Returns:

  • (String)


877
878
879
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 877

def customer_attestation_state
  @customer_attestation_state
end

#domainString

Required. The customer's primary domain. Must match the primary contact email' s domain. Corresponds to the JSON property domain

Returns:

  • (String)


883
884
885
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 883

def domain
  @domain
end

#language_codeString

Optional. The BCP-47 language code, such as "en-US" or "sr-Latn". For more information, see https://www.unicode.org/reports/tr35/# Unicode_locale_identifier. Corresponds to the JSON property languageCode

Returns:

  • (String)


890
891
892
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 890

def language_code
  @language_code
end

#nameString

Output only. Resource name of the customer. Format: accounts/account_id/ customers/customer_id Corresponds to the JSON property name

Returns:

  • (String)


896
897
898
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 896

def name
  @name
end

#org_display_nameString

Required. Name of the organization that the customer entity represents. Corresponds to the JSON property orgDisplayName

Returns:

  • (String)


901
902
903
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 901

def org_display_name
  @org_display_name
end

#org_postal_addressGoogle::Apis::CloudchannelV1::GoogleTypePostalAddress

Represents a postal address, such as for postal delivery or payments addresses. With a postal address, a postal service can deliver items to a premise, P.O. box, or similar. A postal address is not intended to model geographical locations like roads, towns, or mountains. In typical usage, an address would be created by user input or from importing existing data, depending on the type of process. Advice on address input or editing: - Use an internationalization-ready address widget such as https://github.com/google/ libaddressinput. - Users should not be presented with UI elements for input or editing of fields outside countries where that field is used. For more guidance on how to use this schema, see: https://support.google.com/business/ answer/6397478. Corresponds to the JSON property orgPostalAddress



916
917
918
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 916

def org_postal_address
  @org_postal_address
end

#primary_contact_infoGoogle::Apis::CloudchannelV1::GoogleCloudChannelV1ContactInfo

Contact information for a customer account. Corresponds to the JSON property primaryContactInfo



921
922
923
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 921

def primary_contact_info
  @primary_contact_info
end

#update_timeString

Output only. Time when the customer was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


926
927
928
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 926

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



933
934
935
936
937
938
939
940
941
942
943
944
945
946
947
948
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 933

def update!(**args)
  @alternate_email = args[:alternate_email] if args.key?(:alternate_email)
  @channel_partner_id = args[:channel_partner_id] if args.key?(:channel_partner_id)
  @cloud_identity_id = args[:cloud_identity_id] if args.key?(:cloud_identity_id)
  @cloud_identity_info = args[:cloud_identity_info] if args.key?(:cloud_identity_info)
  @correlation_id = args[:correlation_id] if args.key?(:correlation_id)
  @create_time = args[:create_time] if args.key?(:create_time)
  @customer_attestation_state = args[:customer_attestation_state] if args.key?(:customer_attestation_state)
  @domain = args[:domain] if args.key?(:domain)
  @language_code = args[:language_code] if args.key?(:language_code)
  @name = args[:name] if args.key?(:name)
  @org_display_name = args[:org_display_name] if args.key?(:org_display_name)
  @org_postal_address = args[:org_postal_address] if args.key?(:org_postal_address)
  @primary_contact_info = args[:primary_contact_info] if args.key?(:primary_contact_info)
  @update_time = args[:update_time] if args.key?(:update_time)
end