Class: Google::Apis::CloudchannelV1::GoogleCloudChannelV1Entitlement
- Inherits:
-
Object
- Object
- Google::Apis::CloudchannelV1::GoogleCloudChannelV1Entitlement
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudchannel_v1/classes.rb,
lib/google/apis/cloudchannel_v1/representations.rb,
lib/google/apis/cloudchannel_v1/representations.rb
Overview
An entitlement is a representation of a customer's ability to use a service.
Instance Attribute Summary collapse
-
#association_info ⇒ Google::Apis::CloudchannelV1::GoogleCloudChannelV1AssociationInfo
Association links that an entitlement has to other entitlements.
-
#billing_account ⇒ String
Optional.
-
#commitment_settings ⇒ Google::Apis::CloudchannelV1::GoogleCloudChannelV1CommitmentSettings
Commitment settings for commitment-based offers.
-
#create_time ⇒ String
Output only.
-
#name ⇒ String
Output only.
-
#offer ⇒ String
Required.
-
#parameters ⇒ Array<Google::Apis::CloudchannelV1::GoogleCloudChannelV1Parameter>
Extended entitlement parameters.
-
#price_reference_id ⇒ String
Optional.
-
#provisioned_service ⇒ Google::Apis::CloudchannelV1::GoogleCloudChannelV1ProvisionedService
Service provisioned for an entitlement.
-
#provisioning_state ⇒ String
Output only.
-
#purchase_order_id ⇒ String
Optional.
-
#suspension_reasons ⇒ Array<String>
Output only.
-
#trial_settings ⇒ Google::Apis::CloudchannelV1::GoogleCloudChannelV1TrialSettings
Settings for trial offers.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudChannelV1Entitlement
constructor
A new instance of GoogleCloudChannelV1Entitlement.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudChannelV1Entitlement
Returns a new instance of GoogleCloudChannelV1Entitlement.
1273 1274 1275 |
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 1273 def initialize(**args) update!(**args) end |
Instance Attribute Details
#association_info ⇒ Google::Apis::CloudchannelV1::GoogleCloudChannelV1AssociationInfo
Association links that an entitlement has to other entitlements.
Corresponds to the JSON property associationInfo
1189 1190 1191 |
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 1189 def association_info @association_info end |
#billing_account ⇒ String
Optional. The billing account resource name that is used to pay for this
entitlement.
Corresponds to the JSON property billingAccount
1195 1196 1197 |
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 1195 def billing_account @billing_account end |
#commitment_settings ⇒ Google::Apis::CloudchannelV1::GoogleCloudChannelV1CommitmentSettings
Commitment settings for commitment-based offers.
Corresponds to the JSON property commitmentSettings
1200 1201 1202 |
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 1200 def commitment_settings @commitment_settings end |
#create_time ⇒ String
Output only. The time at which the entitlement is created.
Corresponds to the JSON property createTime
1205 1206 1207 |
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 1205 def create_time @create_time end |
#name ⇒ String
Output only. Resource name of an entitlement in the form: accounts/account_id
/customers/customer_id/entitlements/entitlement_id.
Corresponds to the JSON property name
1211 1212 1213 |
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 1211 def name @name end |
#offer ⇒ String
Required. The offer resource name for which the entitlement is to be created.
Takes the form: accounts/account_id/offers/offer_id.
Corresponds to the JSON property offer
1217 1218 1219 |
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 1217 def offer @offer end |
#parameters ⇒ Array<Google::Apis::CloudchannelV1::GoogleCloudChannelV1Parameter>
Extended entitlement parameters. When creating an entitlement, valid parameter
names and values are defined in the Offer.parameter_definitions. For Google
Workspace, the following Parameters may be accepted as input: - max_units: The
maximum assignable units for a flexible offer OR - num_units: The total
commitment for commitment-based offers The response may additionally include
the following output-only Parameters: - assigned_units: The number of licenses
assigned to users. For Google Cloud billing subaccounts, the following
Parameter may be accepted as input: - display_name: The display name of the
billing subaccount.
Corresponds to the JSON property parameters
1230 1231 1232 |
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 1230 def parameters @parameters end |
#price_reference_id ⇒ String
Optional. Price reference ID for the offer. Only for offers that require
additional price information. Used to guarantee that the pricing is consistent
between quoting the offer and placing the order.
Corresponds to the JSON property priceReferenceId
1237 1238 1239 |
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 1237 def price_reference_id @price_reference_id end |
#provisioned_service ⇒ Google::Apis::CloudchannelV1::GoogleCloudChannelV1ProvisionedService
Service provisioned for an entitlement.
Corresponds to the JSON property provisionedService
1242 1243 1244 |
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 1242 def provisioned_service @provisioned_service end |
#provisioning_state ⇒ String
Output only. Current provisioning state of the entitlement.
Corresponds to the JSON property provisioningState
1247 1248 1249 |
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 1247 def provisioning_state @provisioning_state end |
#purchase_order_id ⇒ String
Optional. This purchase order (PO) information is for resellers to use for
their company tracking usage. If a purchaseOrderId value is given, it appears
in the API responses and shows up in the invoice. The property accepts up to
80 plain text characters. This is only supported for Google Workspace
entitlements.
Corresponds to the JSON property purchaseOrderId
1256 1257 1258 |
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 1256 def purchase_order_id @purchase_order_id end |
#suspension_reasons ⇒ Array<String>
Output only. Enumerable of all current suspension reasons for an entitlement.
Corresponds to the JSON property suspensionReasons
1261 1262 1263 |
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 1261 def suspension_reasons @suspension_reasons end |
#trial_settings ⇒ Google::Apis::CloudchannelV1::GoogleCloudChannelV1TrialSettings
Settings for trial offers.
Corresponds to the JSON property trialSettings
1266 1267 1268 |
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 1266 def trial_settings @trial_settings end |
#update_time ⇒ String
Output only. The time at which the entitlement is updated.
Corresponds to the JSON property updateTime
1271 1272 1273 |
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 1271 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1278 1279 1280 1281 1282 1283 1284 1285 1286 1287 1288 1289 1290 1291 1292 1293 |
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 1278 def update!(**args) @association_info = args[:association_info] if args.key?(:association_info) @billing_account = args[:billing_account] if args.key?(:billing_account) @commitment_settings = args[:commitment_settings] if args.key?(:commitment_settings) @create_time = args[:create_time] if args.key?(:create_time) @name = args[:name] if args.key?(:name) @offer = args[:offer] if args.key?(:offer) @parameters = args[:parameters] if args.key?(:parameters) @price_reference_id = args[:price_reference_id] if args.key?(:price_reference_id) @provisioned_service = args[:provisioned_service] if args.key?(:provisioned_service) @provisioning_state = args[:provisioning_state] if args.key?(:provisioning_state) @purchase_order_id = args[:purchase_order_id] if args.key?(:purchase_order_id) @suspension_reasons = args[:suspension_reasons] if args.key?(:suspension_reasons) @trial_settings = args[:trial_settings] if args.key?(:trial_settings) @update_time = args[:update_time] if args.key?(:update_time) end |