Class: Google::Apis::CloudchannelV1::GoogleCloudChannelV1ListOffersResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudchannel_v1/classes.rb,
lib/google/apis/cloudchannel_v1/representations.rb,
lib/google/apis/cloudchannel_v1/representations.rb

Overview

Response message for ListOffers.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudChannelV1ListOffersResponse

Returns a new instance of GoogleCloudChannelV1ListOffersResponse.



1718
1719
1720
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 1718

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

A token to retrieve the next page of results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1710
1711
1712
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 1710

def next_page_token
  @next_page_token
end

#offersArray<Google::Apis::CloudchannelV1::GoogleCloudChannelV1Offer>

The list of Offers requested. The pricing information for each Offer only includes the base price. Effective prices and discounts aren't populated. Corresponds to the JSON property offers



1716
1717
1718
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 1716

def offers
  @offers
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1723
1724
1725
1726
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 1723

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @offers = args[:offers] if args.key?(:offers)
end