Class: Google::Apis::CloudchannelV1::GoogleCloudChannelV1Offer
- Inherits:
-
Object
- Object
- Google::Apis::CloudchannelV1::GoogleCloudChannelV1Offer
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudchannel_v1/classes.rb,
lib/google/apis/cloudchannel_v1/representations.rb,
lib/google/apis/cloudchannel_v1/representations.rb
Overview
Represents an offer made to resellers for purchase. An offer is associated with a Sku, has a plan for payment, a price, and defines the constraints for buying.
Instance Attribute Summary collapse
-
#constraints ⇒ Google::Apis::CloudchannelV1::GoogleCloudChannelV1Constraints
Represents the constraints for buying the Offer.
-
#deal_code ⇒ String
The deal code of the offer to get a special promotion or discount.
-
#end_time ⇒ String
Output only.
-
#marketing_info ⇒ Google::Apis::CloudchannelV1::GoogleCloudChannelV1MarketingInfo
Represents the marketing information for a Product, SKU or Offer.
-
#name ⇒ String
Resource Name of the Offer.
-
#parameter_definitions ⇒ Array<Google::Apis::CloudchannelV1::GoogleCloudChannelV1ParameterDefinition>
Parameters required to use current Offer to purchase.
-
#plan ⇒ Google::Apis::CloudchannelV1::GoogleCloudChannelV1Plan
The payment plan for the Offer.
-
#price_by_resources ⇒ Array<Google::Apis::CloudchannelV1::GoogleCloudChannelV1PriceByResource>
Price for each monetizable resource type.
-
#sku ⇒ Google::Apis::CloudchannelV1::GoogleCloudChannelV1Sku
Represents a product's purchasable Stock Keeping Unit (SKU).
-
#start_time ⇒ String
Start of the Offer validity time.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudChannelV1Offer
constructor
A new instance of GoogleCloudChannelV1Offer.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudChannelV1Offer
Returns a new instance of GoogleCloudChannelV1Offer.
2240 2241 2242 |
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 2240 def initialize(**args) update!(**args) end |
Instance Attribute Details
#constraints ⇒ Google::Apis::CloudchannelV1::GoogleCloudChannelV1Constraints
Represents the constraints for buying the Offer.
Corresponds to the JSON property constraints
2190 2191 2192 |
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 2190 def constraints @constraints end |
#deal_code ⇒ String
The deal code of the offer to get a special promotion or discount.
Corresponds to the JSON property dealCode
2195 2196 2197 |
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 2195 def deal_code @deal_code end |
#end_time ⇒ String
Output only. End of the Offer validity time.
Corresponds to the JSON property endTime
2200 2201 2202 |
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 2200 def end_time @end_time end |
#marketing_info ⇒ Google::Apis::CloudchannelV1::GoogleCloudChannelV1MarketingInfo
Represents the marketing information for a Product, SKU or Offer.
Corresponds to the JSON property marketingInfo
2205 2206 2207 |
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 2205 def marketing_info @marketing_info end |
#name ⇒ String
Resource Name of the Offer. Format: accounts/account_id/offers/offer_id
Corresponds to the JSON property name
2210 2211 2212 |
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 2210 def name @name end |
#parameter_definitions ⇒ Array<Google::Apis::CloudchannelV1::GoogleCloudChannelV1ParameterDefinition>
Parameters required to use current Offer to purchase.
Corresponds to the JSON property parameterDefinitions
2215 2216 2217 |
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 2215 def parameter_definitions @parameter_definitions end |
#plan ⇒ Google::Apis::CloudchannelV1::GoogleCloudChannelV1Plan
The payment plan for the Offer. Describes how to make a payment.
Corresponds to the JSON property plan
2220 2221 2222 |
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 2220 def plan @plan end |
#price_by_resources ⇒ Array<Google::Apis::CloudchannelV1::GoogleCloudChannelV1PriceByResource>
Price for each monetizable resource type.
Corresponds to the JSON property priceByResources
2225 2226 2227 |
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 2225 def price_by_resources @price_by_resources end |
#sku ⇒ Google::Apis::CloudchannelV1::GoogleCloudChannelV1Sku
Represents a product's purchasable Stock Keeping Unit (SKU). SKUs represent
the different variations of the product. For example, Google Workspace
Business Standard and Google Workspace Business Plus are Google Workspace
product SKUs.
Corresponds to the JSON property sku
2233 2234 2235 |
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 2233 def sku @sku end |
#start_time ⇒ String
Start of the Offer validity time.
Corresponds to the JSON property startTime
2238 2239 2240 |
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 2238 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2245 2246 2247 2248 2249 2250 2251 2252 2253 2254 2255 2256 |
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 2245 def update!(**args) @constraints = args[:constraints] if args.key?(:constraints) @deal_code = args[:deal_code] if args.key?(:deal_code) @end_time = args[:end_time] if args.key?(:end_time) @marketing_info = args[:marketing_info] if args.key?(:marketing_info) @name = args[:name] if args.key?(:name) @parameter_definitions = args[:parameter_definitions] if args.key?(:parameter_definitions) @plan = args[:plan] if args.key?(:plan) @price_by_resources = args[:price_by_resources] if args.key?(:price_by_resources) @sku = args[:sku] if args.key?(:sku) @start_time = args[:start_time] if args.key?(:start_time) end |