Class: Google::Apis::CloudchannelV1::GoogleCloudChannelV1Offer

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudchannel_v1/classes.rb,
lib/google/apis/cloudchannel_v1/representations.rb,
lib/google/apis/cloudchannel_v1/representations.rb

Overview

Represents an offer made to resellers for purchase. An offer is associated with a Sku, has a plan for payment, a price, and defines the constraints for buying.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudChannelV1Offer

Returns a new instance of GoogleCloudChannelV1Offer.



2237
2238
2239
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 2237

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#constraintsGoogle::Apis::CloudchannelV1::GoogleCloudChannelV1Constraints

Represents the constraints for buying the Offer. Corresponds to the JSON property constraints



2187
2188
2189
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 2187

def constraints
  @constraints
end

#deal_codeString

The deal code of the offer to get a special promotion or discount. Corresponds to the JSON property dealCode

Returns:

  • (String)


2192
2193
2194
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 2192

def deal_code
  @deal_code
end

#end_timeString

Output only. End of the Offer validity time. Corresponds to the JSON property endTime

Returns:

  • (String)


2197
2198
2199
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 2197

def end_time
  @end_time
end

#marketing_infoGoogle::Apis::CloudchannelV1::GoogleCloudChannelV1MarketingInfo

Represents the marketing information for a Product, SKU or Offer. Corresponds to the JSON property marketingInfo



2202
2203
2204
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 2202

def marketing_info
  @marketing_info
end

#nameString

Resource Name of the Offer. Format: accounts/account_id/offers/offer_id Corresponds to the JSON property name

Returns:

  • (String)


2207
2208
2209
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 2207

def name
  @name
end

#parameter_definitionsArray<Google::Apis::CloudchannelV1::GoogleCloudChannelV1ParameterDefinition>

Parameters required to use current Offer to purchase. Corresponds to the JSON property parameterDefinitions



2212
2213
2214
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 2212

def parameter_definitions
  @parameter_definitions
end

#planGoogle::Apis::CloudchannelV1::GoogleCloudChannelV1Plan

The payment plan for the Offer. Describes how to make a payment. Corresponds to the JSON property plan



2217
2218
2219
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 2217

def plan
  @plan
end

#price_by_resourcesArray<Google::Apis::CloudchannelV1::GoogleCloudChannelV1PriceByResource>

Price for each monetizable resource type. Corresponds to the JSON property priceByResources



2222
2223
2224
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 2222

def price_by_resources
  @price_by_resources
end

#skuGoogle::Apis::CloudchannelV1::GoogleCloudChannelV1Sku

Represents a product's purchasable Stock Keeping Unit (SKU). SKUs represent the different variations of the product. For example, Google Workspace Business Standard and Google Workspace Business Plus are Google Workspace product SKUs. Corresponds to the JSON property sku



2230
2231
2232
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 2230

def sku
  @sku
end

#start_timeString

Start of the Offer validity time. Corresponds to the JSON property startTime

Returns:

  • (String)


2235
2236
2237
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 2235

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2242
2243
2244
2245
2246
2247
2248
2249
2250
2251
2252
2253
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 2242

def update!(**args)
  @constraints = args[:constraints] if args.key?(:constraints)
  @deal_code = args[:deal_code] if args.key?(:deal_code)
  @end_time = args[:end_time] if args.key?(:end_time)
  @marketing_info = args[:marketing_info] if args.key?(:marketing_info)
  @name = args[:name] if args.key?(:name)
  @parameter_definitions = args[:parameter_definitions] if args.key?(:parameter_definitions)
  @plan = args[:plan] if args.key?(:plan)
  @price_by_resources = args[:price_by_resources] if args.key?(:price_by_resources)
  @sku = args[:sku] if args.key?(:sku)
  @start_time = args[:start_time] if args.key?(:start_time)
end