Class: Google::Apis::CloudchannelV1::GoogleCloudChannelV1ProvisionedService
- Inherits:
-
Object
- Object
- Google::Apis::CloudchannelV1::GoogleCloudChannelV1ProvisionedService
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudchannel_v1/classes.rb,
lib/google/apis/cloudchannel_v1/representations.rb,
lib/google/apis/cloudchannel_v1/representations.rb
Overview
Service provisioned for an entitlement.
Instance Attribute Summary collapse
-
#product_id ⇒ String
Output only.
-
#provisioning_id ⇒ String
Output only.
-
#sku_id ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudChannelV1ProvisionedService
constructor
A new instance of GoogleCloudChannelV1ProvisionedService.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudChannelV1ProvisionedService
Returns a new instance of GoogleCloudChannelV1ProvisionedService.
2698 2699 2700 |
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 2698 def initialize(**args) update!(**args) end |
Instance Attribute Details
#product_id ⇒ String
Output only. The product pertaining to the provisioning resource as specified
in the Offer.
Corresponds to the JSON property productId
2683 2684 2685 |
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 2683 def product_id @product_id end |
#provisioning_id ⇒ String
Output only. Provisioning ID of the entitlement. For Google Workspace, this is
the underlying Subscription ID. For Google Cloud, this is the Billing Account
ID of the billing subaccount.
Corresponds to the JSON property provisioningId
2690 2691 2692 |
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 2690 def provisioning_id @provisioning_id end |
#sku_id ⇒ String
Output only. The SKU pertaining to the provisioning resource as specified in
the Offer.
Corresponds to the JSON property skuId
2696 2697 2698 |
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 2696 def sku_id @sku_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2703 2704 2705 2706 2707 |
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 2703 def update!(**args) @product_id = args[:product_id] if args.key?(:product_id) @provisioning_id = args[:provisioning_id] if args.key?(:provisioning_id) @sku_id = args[:sku_id] if args.key?(:sku_id) end |