Class: Google::Apis::CloudchannelV1::GoogleCloudChannelV1ProvisionedService

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudchannel_v1/classes.rb,
lib/google/apis/cloudchannel_v1/representations.rb,
lib/google/apis/cloudchannel_v1/representations.rb

Overview

Service provisioned for an entitlement.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudChannelV1ProvisionedService

Returns a new instance of GoogleCloudChannelV1ProvisionedService.



2695
2696
2697
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 2695

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#product_idString

Output only. The product pertaining to the provisioning resource as specified in the Offer. Corresponds to the JSON property productId

Returns:

  • (String)


2680
2681
2682
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 2680

def product_id
  @product_id
end

#provisioning_idString

Output only. Provisioning ID of the entitlement. For Google Workspace, this is the underlying Subscription ID. For Google Cloud, this is the Billing Account ID of the billing subaccount. Corresponds to the JSON property provisioningId

Returns:

  • (String)


2687
2688
2689
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 2687

def provisioning_id
  @provisioning_id
end

#sku_idString

Output only. The SKU pertaining to the provisioning resource as specified in the Offer. Corresponds to the JSON property skuId

Returns:

  • (String)


2693
2694
2695
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 2693

def sku_id
  @sku_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2700
2701
2702
2703
2704
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 2700

def update!(**args)
  @product_id = args[:product_id] if args.key?(:product_id)
  @provisioning_id = args[:provisioning_id] if args.key?(:provisioning_id)
  @sku_id = args[:sku_id] if args.key?(:sku_id)
end