Class: Google::Apis::CloudchannelV1::GoogleCloudChannelV1Sku
- Inherits:
-
Object
- Object
- Google::Apis::CloudchannelV1::GoogleCloudChannelV1Sku
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudchannel_v1/classes.rb,
lib/google/apis/cloudchannel_v1/representations.rb,
lib/google/apis/cloudchannel_v1/representations.rb
Overview
Represents a product's purchasable Stock Keeping Unit (SKU). SKUs represent the different variations of the product. For example, Google Workspace Business Standard and Google Workspace Business Plus are Google Workspace product SKUs.
Instance Attribute Summary collapse
-
#marketing_info ⇒ Google::Apis::CloudchannelV1::GoogleCloudChannelV1MarketingInfo
Represents the marketing information for a Product, SKU or Offer.
-
#name ⇒ String
Resource Name of the SKU.
-
#product ⇒ Google::Apis::CloudchannelV1::GoogleCloudChannelV1Product
A Product is the entity a customer uses when placing an order.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudChannelV1Sku
constructor
A new instance of GoogleCloudChannelV1Sku.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudChannelV1Sku
Returns a new instance of GoogleCloudChannelV1Sku.
3337 3338 3339 |
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 3337 def initialize(**args) update!(**args) end |
Instance Attribute Details
#marketing_info ⇒ Google::Apis::CloudchannelV1::GoogleCloudChannelV1MarketingInfo
Represents the marketing information for a Product, SKU or Offer.
Corresponds to the JSON property marketingInfo
3324 3325 3326 |
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 3324 def marketing_info @marketing_info end |
#name ⇒ String
Resource Name of the SKU. Format: products/product_id/skus/sku_id
Corresponds to the JSON property name
3329 3330 3331 |
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 3329 def name @name end |
#product ⇒ Google::Apis::CloudchannelV1::GoogleCloudChannelV1Product
A Product is the entity a customer uses when placing an order. For example,
Google Workspace, Google Voice, etc.
Corresponds to the JSON property product
3335 3336 3337 |
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 3335 def product @product end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3342 3343 3344 3345 3346 |
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 3342 def update!(**args) @marketing_info = args[:marketing_info] if args.key?(:marketing_info) @name = args[:name] if args.key?(:name) @product = args[:product] if args.key?(:product) end |