Class: Google::Apis::CloudchannelV1::GoogleCloudChannelV1Sku

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudchannel_v1/classes.rb,
lib/google/apis/cloudchannel_v1/representations.rb,
lib/google/apis/cloudchannel_v1/representations.rb

Overview

Represents a product's purchasable Stock Keeping Unit (SKU). SKUs represent the different variations of the product. For example, Google Workspace Business Standard and Google Workspace Business Plus are Google Workspace product SKUs.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudChannelV1Sku

Returns a new instance of GoogleCloudChannelV1Sku.



3334
3335
3336
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 3334

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#marketing_infoGoogle::Apis::CloudchannelV1::GoogleCloudChannelV1MarketingInfo

Represents the marketing information for a Product, SKU or Offer. Corresponds to the JSON property marketingInfo



3321
3322
3323
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 3321

def marketing_info
  @marketing_info
end

#nameString

Resource Name of the SKU. Format: products/product_id/skus/sku_id Corresponds to the JSON property name

Returns:

  • (String)


3326
3327
3328
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 3326

def name
  @name
end

#productGoogle::Apis::CloudchannelV1::GoogleCloudChannelV1Product

A Product is the entity a customer uses when placing an order. For example, Google Workspace, Google Voice, etc. Corresponds to the JSON property product



3332
3333
3334
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 3332

def product
  @product
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3339
3340
3341
3342
3343
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 3339

def update!(**args)
  @marketing_info = args[:marketing_info] if args.key?(:marketing_info)
  @name = args[:name] if args.key?(:name)
  @product = args[:product] if args.key?(:product)
end