Class: Google::Apis::CloudchannelV1::GoogleCloudChannelV1TransferableOffer
- Inherits:
-
Object
- Object
- Google::Apis::CloudchannelV1::GoogleCloudChannelV1TransferableOffer
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudchannel_v1/classes.rb,
lib/google/apis/cloudchannel_v1/representations.rb,
lib/google/apis/cloudchannel_v1/representations.rb
Overview
TransferableOffer represents an Offer that can be used in Transfer. Read-only.
Instance Attribute Summary collapse
-
#offer ⇒ Google::Apis::CloudchannelV1::GoogleCloudChannelV1Offer
Represents an offer made to resellers for purchase.
-
#price_reference_id ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudChannelV1TransferableOffer
constructor
A new instance of GoogleCloudChannelV1TransferableOffer.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudChannelV1TransferableOffer
Returns a new instance of GoogleCloudChannelV1TransferableOffer.
3641 3642 3643 |
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 3641 def initialize(**args) update!(**args) end |
Instance Attribute Details
#offer ⇒ Google::Apis::CloudchannelV1::GoogleCloudChannelV1Offer
Represents an offer made to resellers for purchase. An offer is associated
with a Sku, has a plan for payment, a price, and defines the constraints for
buying.
Corresponds to the JSON property offer
3632 3633 3634 |
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 3632 def offer @offer end |
#price_reference_id ⇒ String
Optional. Price reference ID for the offer. Only for offers that require
additional price information. Used to guarantee that the pricing is consistent
between quoting the offer and placing the order.
Corresponds to the JSON property priceReferenceId
3639 3640 3641 |
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 3639 def price_reference_id @price_reference_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3646 3647 3648 3649 |
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 3646 def update!(**args) @offer = args[:offer] if args.key?(:offer) @price_reference_id = args[:price_reference_id] if args.key?(:price_reference_id) end |