Class: Google::Apis::CloudchannelV1::GoogleCloudChannelV1TransferableSku

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudchannel_v1/classes.rb,
lib/google/apis/cloudchannel_v1/representations.rb,
lib/google/apis/cloudchannel_v1/representations.rb

Overview

TransferableSku represents information a reseller needs to view existing provisioned services for a customer that they do not own. Read-only.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudChannelV1TransferableSku

Returns a new instance of GoogleCloudChannelV1TransferableSku.



3678
3679
3680
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 3678

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#legacy_skuGoogle::Apis::CloudchannelV1::GoogleCloudChannelV1Sku

Represents a product's purchasable Stock Keeping Unit (SKU). SKUs represent the different variations of the product. For example, Google Workspace Business Standard and Google Workspace Business Plus are Google Workspace product SKUs. Corresponds to the JSON property legacySku



3663
3664
3665
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 3663

def legacy_sku
  @legacy_sku
end

#skuGoogle::Apis::CloudchannelV1::GoogleCloudChannelV1Sku

Represents a product's purchasable Stock Keeping Unit (SKU). SKUs represent the different variations of the product. For example, Google Workspace Business Standard and Google Workspace Business Plus are Google Workspace product SKUs. Corresponds to the JSON property sku



3671
3672
3673
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 3671

def sku
  @sku
end

#transfer_eligibilityGoogle::Apis::CloudchannelV1::GoogleCloudChannelV1TransferEligibility

Specifies transfer eligibility of a SKU. Corresponds to the JSON property transferEligibility



3676
3677
3678
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 3676

def transfer_eligibility
  @transfer_eligibility
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3683
3684
3685
3686
3687
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 3683

def update!(**args)
  @legacy_sku = args[:legacy_sku] if args.key?(:legacy_sku)
  @sku = args[:sku] if args.key?(:sku)
  @transfer_eligibility = args[:transfer_eligibility] if args.key?(:transfer_eligibility)
end