Class: Google::Apis::CloudchannelV1::GoogleCloudChannelV1alpha1Entitlement
- Inherits:
-
Object
- Object
- Google::Apis::CloudchannelV1::GoogleCloudChannelV1alpha1Entitlement
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudchannel_v1/classes.rb,
lib/google/apis/cloudchannel_v1/representations.rb,
lib/google/apis/cloudchannel_v1/representations.rb
Overview
An entitlement is a representation of a customer's ability to use a service.
Instance Attribute Summary collapse
-
#assigned_units ⇒ Fixnum
The current number of users that are assigned a license for the product defined in provisioned_service.skuId.
-
#association_info ⇒ Google::Apis::CloudchannelV1::GoogleCloudChannelV1alpha1AssociationInfo
Association links that an entitlement has to other entitlements.
-
#billing_account ⇒ String
Optional.
-
#channel_partner_id ⇒ String
Cloud Identity ID of a channel partner who will be the direct reseller for the customer's order.
-
#commitment_settings ⇒ Google::Apis::CloudchannelV1::GoogleCloudChannelV1alpha1CommitmentSettings
Commitment settings for commitment-based offers.
-
#create_time ⇒ String
Output only.
-
#max_units ⇒ Fixnum
Maximum number of units for a non commitment-based Offer, such as Flexible, Trial or Free entitlements.
-
#name ⇒ String
Output only.
-
#num_units ⇒ Fixnum
Number of units for a commitment-based Offer.
-
#offer ⇒ String
Required.
-
#parameters ⇒ Array<Google::Apis::CloudchannelV1::GoogleCloudChannelV1alpha1Parameter>
Extended entitlement parameters.
-
#price_reference_id ⇒ String
Optional.
-
#provisioned_service ⇒ Google::Apis::CloudchannelV1::GoogleCloudChannelV1alpha1ProvisionedService
Service provisioned for an entitlement.
-
#provisioning_state ⇒ String
Output only.
-
#purchase_order_id ⇒ String
Optional.
-
#suspension_reasons ⇒ Array<String>
Output only.
-
#trial_settings ⇒ Google::Apis::CloudchannelV1::GoogleCloudChannelV1alpha1TrialSettings
Settings for trial offers.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudChannelV1alpha1Entitlement
constructor
A new instance of GoogleCloudChannelV1alpha1Entitlement.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudChannelV1alpha1Entitlement
Returns a new instance of GoogleCloudChannelV1alpha1Entitlement.
4178 4179 4180 |
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 4178 def initialize(**args) update!(**args) end |
Instance Attribute Details
#assigned_units ⇒ Fixnum
The current number of users that are assigned a license for the product
defined in provisioned_service.skuId. Read-only. Deprecated: Use parameters
instead.
Corresponds to the JSON property assignedUnits
4064 4065 4066 |
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 4064 def assigned_units @assigned_units end |
#association_info ⇒ Google::Apis::CloudchannelV1::GoogleCloudChannelV1alpha1AssociationInfo
Association links that an entitlement has to other entitlements.
Corresponds to the JSON property associationInfo
4069 4070 4071 |
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 4069 def association_info @association_info end |
#billing_account ⇒ String
Optional. The billing account resource name that is used to pay for this
entitlement.
Corresponds to the JSON property billingAccount
4075 4076 4077 |
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 4075 def billing_account @billing_account end |
#channel_partner_id ⇒ String
Cloud Identity ID of a channel partner who will be the direct reseller for the
customer's order. This field is generally used in 2-tier ordering, where the
order is placed by a top-level distributor on behalf of their channel partner
or reseller. Required for distributors. Deprecated: channel_partner_id has
been moved to the Customer.
Corresponds to the JSON property channelPartnerId
4084 4085 4086 |
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 4084 def channel_partner_id @channel_partner_id end |
#commitment_settings ⇒ Google::Apis::CloudchannelV1::GoogleCloudChannelV1alpha1CommitmentSettings
Commitment settings for commitment-based offers.
Corresponds to the JSON property commitmentSettings
4089 4090 4091 |
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 4089 def commitment_settings @commitment_settings end |
#create_time ⇒ String
Output only. The time at which the entitlement is created.
Corresponds to the JSON property createTime
4094 4095 4096 |
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 4094 def create_time @create_time end |
#max_units ⇒ Fixnum
Maximum number of units for a non commitment-based Offer, such as Flexible,
Trial or Free entitlements. For commitment-based entitlements, this is a read-
only field, which only the internal support team can update. Deprecated: Use
parameters instead.
Corresponds to the JSON property maxUnits
4102 4103 4104 |
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 4102 def max_units @max_units end |
#name ⇒ String
Output only. Resource name of an entitlement in the form: accounts/account_id
/customers/customer_id/entitlements/entitlement_id.
Corresponds to the JSON property name
4108 4109 4110 |
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 4108 def name @name end |
#num_units ⇒ Fixnum
Number of units for a commitment-based Offer. For example, for seat-based
Offers, this would be the number of seats; for license-based Offers, this
would be the number of licenses. Required for creating commitment-based Offers.
Deprecated: Use parameters instead.
Corresponds to the JSON property numUnits
4116 4117 4118 |
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 4116 def num_units @num_units end |
#offer ⇒ String
Required. The offer resource name for which the entitlement is to be created.
Takes the form: accounts/account_id/offers/offer_id.
Corresponds to the JSON property offer
4122 4123 4124 |
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 4122 def offer @offer end |
#parameters ⇒ Array<Google::Apis::CloudchannelV1::GoogleCloudChannelV1alpha1Parameter>
Extended entitlement parameters. When creating an entitlement, valid parameter
names and values are defined in the Offer.parameter_definitions. For Google
Workspace, the following Parameters may be accepted as input: - max_units: The
maximum assignable units for a flexible offer OR - num_units: The total
commitment for commitment-based offers The response may additionally include
the following output-only Parameters: - assigned_units: The number of licenses
assigned to users. For Google Cloud billing subaccounts, the following
Parameter may be accepted as input: - display_name: The display name of the
billing subaccount.
Corresponds to the JSON property parameters
4135 4136 4137 |
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 4135 def parameters @parameters end |
#price_reference_id ⇒ String
Optional. Price reference ID for the offer. Only for offers that require
additional price information. Used to guarantee that the pricing is consistent
between quoting the offer and placing the order.
Corresponds to the JSON property priceReferenceId
4142 4143 4144 |
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 4142 def price_reference_id @price_reference_id end |
#provisioned_service ⇒ Google::Apis::CloudchannelV1::GoogleCloudChannelV1alpha1ProvisionedService
Service provisioned for an entitlement.
Corresponds to the JSON property provisionedService
4147 4148 4149 |
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 4147 def provisioned_service @provisioned_service end |
#provisioning_state ⇒ String
Output only. Current provisioning state of the entitlement.
Corresponds to the JSON property provisioningState
4152 4153 4154 |
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 4152 def provisioning_state @provisioning_state end |
#purchase_order_id ⇒ String
Optional. This purchase order (PO) information is for resellers to use for
their company tracking usage. If a purchaseOrderId value is given, it appears
in the API responses and shows up in the invoice. The property accepts up to
80 plain text characters. This is only supported for Google Workspace
entitlements.
Corresponds to the JSON property purchaseOrderId
4161 4162 4163 |
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 4161 def purchase_order_id @purchase_order_id end |
#suspension_reasons ⇒ Array<String>
Output only. Enumerable of all current suspension reasons for an entitlement.
Corresponds to the JSON property suspensionReasons
4166 4167 4168 |
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 4166 def suspension_reasons @suspension_reasons end |
#trial_settings ⇒ Google::Apis::CloudchannelV1::GoogleCloudChannelV1alpha1TrialSettings
Settings for trial offers.
Corresponds to the JSON property trialSettings
4171 4172 4173 |
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 4171 def trial_settings @trial_settings end |
#update_time ⇒ String
Output only. The time at which the entitlement is updated.
Corresponds to the JSON property updateTime
4176 4177 4178 |
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 4176 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4183 4184 4185 4186 4187 4188 4189 4190 4191 4192 4193 4194 4195 4196 4197 4198 4199 4200 4201 4202 |
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 4183 def update!(**args) @assigned_units = args[:assigned_units] if args.key?(:assigned_units) @association_info = args[:association_info] if args.key?(:association_info) @billing_account = args[:billing_account] if args.key?(:billing_account) @channel_partner_id = args[:channel_partner_id] if args.key?(:channel_partner_id) @commitment_settings = args[:commitment_settings] if args.key?(:commitment_settings) @create_time = args[:create_time] if args.key?(:create_time) @max_units = args[:max_units] if args.key?(:max_units) @name = args[:name] if args.key?(:name) @num_units = args[:num_units] if args.key?(:num_units) @offer = args[:offer] if args.key?(:offer) @parameters = args[:parameters] if args.key?(:parameters) @price_reference_id = args[:price_reference_id] if args.key?(:price_reference_id) @provisioned_service = args[:provisioned_service] if args.key?(:provisioned_service) @provisioning_state = args[:provisioning_state] if args.key?(:provisioning_state) @purchase_order_id = args[:purchase_order_id] if args.key?(:purchase_order_id) @suspension_reasons = args[:suspension_reasons] if args.key?(:suspension_reasons) @trial_settings = args[:trial_settings] if args.key?(:trial_settings) @update_time = args[:update_time] if args.key?(:update_time) end |