Class: Google::Apis::CloudchannelV1::GoogleCloudChannelV1alpha1ProvisionedService

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudchannel_v1/classes.rb,
lib/google/apis/cloudchannel_v1/representations.rb,
lib/google/apis/cloudchannel_v1/representations.rb

Overview

Service provisioned for an entitlement.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudChannelV1alpha1ProvisionedService

Returns a new instance of GoogleCloudChannelV1alpha1ProvisionedService.



4363
4364
4365
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 4363

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#product_idString

Output only. The product pertaining to the provisioning resource as specified in the Offer. Corresponds to the JSON property productId

Returns:

  • (String)


4348
4349
4350
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 4348

def product_id
  @product_id
end

#provisioning_idString

Output only. Provisioning ID of the entitlement. For Google Workspace, this is the underlying Subscription ID. For Google Cloud, this is the Billing Account ID of the billing subaccount. Corresponds to the JSON property provisioningId

Returns:

  • (String)


4355
4356
4357
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 4355

def provisioning_id
  @provisioning_id
end

#sku_idString

Output only. The SKU pertaining to the provisioning resource as specified in the Offer. Corresponds to the JSON property skuId

Returns:

  • (String)


4361
4362
4363
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 4361

def sku_id
  @sku_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4368
4369
4370
4371
4372
# File 'lib/google/apis/cloudchannel_v1/classes.rb', line 4368

def update!(**args)
  @product_id = args[:product_id] if args.key?(:product_id)
  @provisioning_id = args[:provisioning_id] if args.key?(:provisioning_id)
  @sku_id = args[:sku_id] if args.key?(:sku_id)
end